doapfiend.plugins.pkg_index

Package doapfiend :: Package plugins :: Module pkg_index |
[hide private]
[frames] | no frames]

# Module pkg_index

source code

Plugin helper to fetch a single DOAP file from doapspace.org by Package Index

Functions | [hide private]
string |
get_by_pkg_index(index, project_name, proxy=None) Get DOAP for a package index project name from doapspace.org | source code

Variables | [hide private]
| PKG_INDEX_URI = ``'``http://doapspace.org/doap``'``
| OHLOH_URI = ``'``http://rdfohloh.wikier.org/project/``'``

Function Details | [hide private]

### get_by_pkg_index(index, project_name, proxy=None) | source code
Get DOAP for a package index project name from doapspace.org Builtin indexes: 'sf' SourceForge 'fm' Freshmeat 'py' Python Package Index 'oh' Project listed on Ohlo Raises doaplib.utils.NotFound exception on HTTP 404 error Parameters: `index` (string) - Package index two letter abbreviation `project_name` (string) - project name `proxy` (string) - Optional HTTP proxy URL Returns: string text of file retrieved